@@ -1,5 +1,5 @@
 qat_call_save_set_nans <-
-function(resultlist_part, element = -999, time = NULL, height = NULL, lat = NULL, lon = NULL, vec1 = NULL, vec2 = NULL, vec3 = NULL, vec4 = NULL, baseunit = NULL, savelist = list(), savelistcounter = 1) {
+function(resultlist_part, element = -999, dim_mv=1, time = NULL, height = NULL, lat = NULL, lon = NULL, vec1 = NULL, vec2 = NULL, vec3 = NULL, vec4 = NULL, baseunit = NULL, savelist = list(), savelistcounter = 1) {
 ## functionality: calling save function for qat_save_set_nans_1d, qat_save_set_nans_above_1d and qat_save_set_nans_below_1d
 ## author: André Düsterhus
 ## date: 21.04.2011
